Entry

Struct Entry 

pub struct Entry {
    pub mode: u32,
    pub name: OsString,
    pub hash: Vec<u8>,
}
Entry Struct

This struct contains blob( or tree) object’s mode, name, hash. Since blob and tree do not know their own names, it is necessary to string them together in this structure.

Fields

mode: u32name: OsStringhash: Vec<u8>

Implementations

Source

impl Entry

pub fn new<P: AsRef<Path>>(path: P, object: Object) -> Result<Self>

pub fn new_group<P: AsRef<Path>>(path: P, entries: Vec<Entry>) -> Result<Self>

pub fn as_bytes(&self) -> Vec<u8>

pub fn as_type(&self) -> &str