pub struct Entry {
pub mode: u32,
pub name: OsString,
pub hash: Vec<u8>,
}Expand description
Entry Struct
This struct contains blob( or tree) object’s mode, name, hash. Since blob and tree do not know their own names, it is necessary to string them together in this structure.
Fields
mode: u32name: OsStringhash: Vec<u8>Implementations